@@ -50,7 +50,7 @@ use Slaughter::Private;
 #
 # The version of our release.
 #
-our $VERSION = "3.0.5";
+our $VERSION = "3.0.6";
 
 
 =head2 import
@@ -297,16 +297,21 @@ sub CommentLinesMatching
                 }
                 close($handle);
 
+                $::verbose &&
+                  print "Commented $found lines matching $pattern in $file\n";
+
                 return $found;
             }
         }
         else
         {
+            $::verbose && print "No lines matching $pattern found in $file\n";
             return 0;
         }
     }
     else
     {
+        $::verbose && print "Couldn't open $file to check for $pattern\n";
         return -1;
     }
 }
@@ -939,7 +944,7 @@ sub FindBinary
     my $binary = $params{ 'Binary' } || $params{ 'binary' } || return;
     my $path = $params{ 'Path' } ||
       $params{ 'path' } ||
-      $ENV{ 'PATH' } ||
+      $ENV{ 'PATH' }    ||
       "/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin";
     my $result = undef;
 
@@ -1422,7 +1427,8 @@ sub SetPermissions
         my ( $dev,      $ino,     $mode, $nlink, $orig_uid,
              $orig_gid, $rdev,    $size, $atime, $mtime,
              $ctime,    $blksize, $blocks
-           ) = stat($file);
+           )
+          = stat($file);
 
         $::verbose && print "\tSetting owner to $owner/$uid\n";
         chown( $uid, $orig_gid, $file );
@@ -1439,7 +1445,8 @@ sub SetPermissions
         my ( $dev,      $ino,     $mode, $nlink, $orig_uid,
              $orig_gid, $rdev,    $size, $atime, $mtime,
              $ctime,    $blksize, $blocks
-           ) = stat($file);
+           )
+          = stat($file);
 
         $::verbose && print "\tSetting group to $group/$gid\n";
         chown( $orig_uid, $gid, $file );
@@ -1543,7 +1550,8 @@ sub UserDetails
     #
     #  Return the values as a hash
     #
-    return ( { Home    => $home,
+    return (
+             { Home    => $home,
                UID     => $uid,
                GID     => $gid,
                Quota   => $quota,
